Enum MidiMessageBytes

pub enum MidiMessageBytes {
    Status(StatusByte),
    Single(StatusByte, DataByte),
    Double(StatusByte, DataByte, DataByte),
}
There are only three types of midi message bytes:

1.  |--------|
    | Status |
    |--------|

2.  |--------|   |------|
    | Status | - | Data |
    |--------|   |------|

3.  |--------|   |------|   |------|
    | Status | - | Data | - | Data |
    |--------|   |------|   |------|

Variants



Status(StatusByte)

Message is only one byte



Single(StatusByte, DataByte)

Message is a StatusByte and a DataByte



Double(StatusByte, DataByte, DataByte)

Message is a StatusByte and two DataBytes

Implementations

Source

impl MidiMessageBytes

pub fn write<W: Write + ?Sized>(&self, writer: &mut W) -> Result<(), Error>

Write the contents of self into some writer as MIDI bytes

pub fn from_status<B, E>(status: B) -> Result<Self, Error>
where B: TryInto<StatusByte, Error = E>, E: Into<Error>,

Create a MidiMessageByte from a single status byte. Errors if leading 1 is not found.