Module events

Module events 

The “root” event types for live streams and files

Enums

ChunkEvent
Reads the full length of all chunk types
FileEvent
An event that can be yielded from or put into a .mid file.
LiveEvent
An emittable message to/from a streaming MIDI device.

Traits

FromLiveEventBytes
Identifies something that can be interpreted from the bytes of a live MIDI stream