The “root” event types for live streams and files
Enums
- Chunk
Event - Reads the full length of all chunk types
- File
Event - An event that can be yielded from or put into a
.midfile. - Live
Event - An emittable message to/from a streaming MIDI device.
Traits
- From
Live Event Bytes - Identifies something that can be interpreted from the bytes of a live MIDI stream